CancellableEvent mixin

Mixin for events that can be cancelled.

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether this event has been cancelled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When the event occurred.
finalinherited

Methods

cancel() → void
Cancel this event, preventing further processing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited