ColumnDriverOverride class

Driver-specific column hints that override the default definition.

Annotations
  • @immutable

Constructors

ColumnDriverOverride({ColumnType? type, String? sqlType, ColumnDefault? defaultValue, String? collation, String? charset})
const
ColumnDriverOverride.fromJson(Map<String, Object?> json)
factory

Properties

charset → String?
Character set override for the column.
final
collation → String?
Collation override for the column.
final
defaultValue → ColumnDefault?
Default value applied by the driver.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlType → String?
Raw SQL type string for the driver.
final
type → ColumnType?
Logical column type assigned to this driver override.
final

Methods

merge(ColumnDriverOverride other) → ColumnDriverOverride
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited