DriverExtensionHandler class

Handler for a driver extension clause.

Constructors

DriverExtensionHandler({required DriverExtensionKind kind, required String key, required DriverExtensionCompiler compile})
const

Properties

compile DriverExtensionCompiler
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
kind DriverExtensionKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited