FilterClause class

Filter clause applied to a single column.

Constructors

FilterClause({required String field, required FilterOperator operator, required Object? value, bool compile = true})
const

Properties

compile bool
final
field String
final
hashCode int
The hash code for this object.
no setterinherited
operator FilterOperator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited