rightJoin method

Query<T> rightJoin(
  1. Object table,
  2. Object constraint, [
  3. Object? operator,
  4. Object? second,
])

Adds a RIGHT JOIN clause to the query.

The table parameter can be a table name (String) or a subquery (Query). The constraint parameter can be a column name (String) or a JoinConstraintBuilder callback for more complex join conditions.

Example:

final profilesWithOptionalUsers = await context.query<Profile>()
  .rightJoin('users', 'profiles.user_id', '=', 'users.id')
  .get();

Implementation

Query<T> rightJoin(
  Object table,
  Object constraint, [
  Object? operator,
  Object? second,
]) => _join(
  target: _resolveJoinTarget(table),
  type: JoinType.right,
  constraint: constraint,
  operator: operator,
  second: second,
);