JoinType enum
Supported JOIN clause types applied by the grammar.
These types correspond to the various SQL JOIN operations that can be performed when building queries.
Values
- inner → const JoinType
-
Corresponds to
INNER JOIN. Returns only the rows that have matching values in both tables. - left → const JoinType
-
Corresponds to
LEFT JOIN(orLEFT OUTER JOIN). Returns all rows from the left table, and the matching rows from the right table. If there is no match, the right side will haveNULLs. - right → const JoinType
-
Corresponds to
RIGHT JOIN(orRIGHT OUTER JOIN). Returns all rows from the right table, and the matching rows from the left table. If there is no match, the left side will haveNULLs. - cross → const JoinType
-
Corresponds to
CROSS JOIN. Returns the Cartesian product of the rows from the joined tables. - straight → const JoinType
-
Corresponds to
STRAIGHT_JOIN. Forces the optimizer to join tables in the order in which they are listed in theFROMclause. This is a MySQL/MariaDB specific join type.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited