ModelCodec<TModel> class abstract

Base contract for generated model codecs.

Constructors

ModelCodec()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Map<String, Object?> data, ValueCodecRegistry registry) → TModel
Decodes a map to a model instance.
encode(TModel model, ValueCodecRegistry registry) → Map<String, Object?>
Encodes a model instance to a map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited