OrmedTestConfig class

Global test counter for unique IDs Configuration object returned by setUpOrmed. Pass this to ormedGroup to ensure the correct manager is used.

Properties

configHash String
Hash of the configuration used to create this test environment.
no setter
configKey String
Unique key identifying this test configuration
final
dataSource DataSource
Get the DataSource for this configuration
no setter
dataSourceName String
The DataSource name
final
hashCode int
The hash code for this object.
no setterinherited
manager TestDatabaseManager
Get the manager for this configuration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited