SeederStartedEvent class

Event emitted when a single seeder starts.

Inheritance

Constructors

SeederStartedEvent({required String seederName, required int index, required int total, DateTime? timestamp})

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
1-based index of current seeder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seederName → String
Name of the seeder class.
final
timestamp → DateTime
When the event occurred.
finalinherited
total → int
Total seeders to run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited