SelectExtension<T extends OrmEntity> extension

Extension providing SELECT clause and projection methods for query results.

on

Methods

addSelect(String column) Query<T>

Available on Query<T>, provided by the SelectExtension extension

Adds a single column to the select projection.
select(List<String> columns) Query<T>

Available on Query<T>, provided by the SelectExtension extension

Only the specified columns will be retrieved from the database.
selectExtension(String key, {Object? payload, String? alias}) Query<T>

Available on Query<T>, provided by the SelectExtension extension

Adds a custom select expression compiled by a driver extension.
selectRaw(String sql, {String? alias, List<Object?> bindings = const []}) Query<T>

Available on Query<T>, provided by the SelectExtension extension

Adds a raw select expression with optional bindings.
value<R>(String field) Future<R?>

Available on Query<T>, provided by the SelectExtension extension

Returns the value of field from the first row, or null when missing.