hasBatches property
bool
get
hasBatches
Whether the preview represents multiple executions of the same statement.
Implementation
bool get hasBatches => _parameterSets.isNotEmpty;
Whether the preview represents multiple executions of the same statement.
bool get hasBatches => _parameterSets.isNotEmpty;