TransactionRolledBack class

Fired after a transaction rolls back.

Example

connection.onEvent<TransactionRolledBack>((event) {
  print('Transaction rolled back on ${event.connectionName}');
  logger.warning('Transaction failed');
});
Inheritance

Constructors

TransactionRolledBack(OrmConnection connection, {DateTime? timestamp})

Properties

connection → OrmConnection
The connection where this event occurred.
finalinherited
connectionName → String
The name of the connection (convenience accessor).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
When the event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited