ConnectionResolver class abstract
Describes a runtime context capable of executing ORM queries.
- Implementers
Constructors
Properties
- codecRegistry → ValueCodecRegistry
-
Codec registry scoped to the current connection.
no setter
- driver → DriverAdapter
-
Database adapter backing this resolver.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- registry → ModelRegistry
-
Registry of model definitions available to this resolver.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
describeMutation(
MutationPlan plan) → StatementPreview -
Provides the statement preview for a write
plan. -
describeQuery(
QueryPlan plan) → StatementPreview -
Provides the statement preview for a read
plan. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runMutation(
MutationPlan plan) → Future< MutationResult> -
Executes a write
planand returns the driver result. -
runSelect(
QueryPlan plan) → Future< List< Map< >String, Object?> > -
Executes a read
planand returns the raw rows. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited