FieldDriverOverride class
Driver-specific metadata for a field definition.
Constructors
- FieldDriverOverride({String? columnType, String? defaultValueSql, String? codecType})
-
const
Properties
- codecType → String?
-
Driver-specific codec type override.
final
- columnType → String?
-
Driver-specific column type override.
final
- defaultValueSql → String?
-
Driver-specific default value SQL override.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited