MigrationBatchCompletedEvent class
Event emitted when a migration batch completes.
- Inheritance
-
- Object
- Event
- MigrationEvent
- MigrationBatchCompletedEvent
Constructors
- MigrationBatchCompletedEvent({required MigrationDirection direction, required int count, required Duration duration, DateTime? timestamp})
Properties
- count → int
-
Number of migrations processed.
final
- direction → MigrationDirection
-
Whether applied or rolled back.
final
- duration → Duration
-
Total duration of the batch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited