MigrationStartedEvent class
Event emitted when a single migration starts.
- Inheritance
-
- Object
- Event
- MigrationEvent
- MigrationStartedEvent
Constructors
- MigrationStartedEvent({required String migrationId, required String migrationName, required MigrationDirection direction, required int index, required int total, DateTime? timestamp})
Properties
- direction → MigrationDirection
-
Whether applying or rolling back.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
1-based index of current migration in batch.
final
- migrationId → String
-
The migration ID.
final
- migrationName → String
-
Human-readable migration name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the event occurred.
finalinherited
- total → int
-
Total migrations in batch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited